==> mono_1.1.17.1.orig.tar.gz: mono-1.1.17.1/mcs/class/System/System.Net.Configuration/SmtpSection.cs <==
//
// System.Net.Configuration.SmtpSection
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0 && CONFIGURATION_DEP

using System;
using System.Configuration;
using System.Net.Mail;

namespace System.Net.Configuration {

        public sealed class SmtpSection : ConfigurationSection
        {
                static ConfigurationProperty deliveryMethodProp;
                static ConfigurationProperty fromProp;
                static ConfigurationProperty networkProp;
                static ConfigurationProperty specifiedPickupDirectoryProp;
                static ConfigurationPropertyCollection properties;

                static SmtpSection ()
                {
                        deliveryMethodProp = new ConfigurationProperty ("deliveryMethod", typeof (SmtpDeliveryMethod), SmtpDeliveryMethod.Network);
                        fromProp = new ConfigurationProperty ("from", typeof (string));
                        networkProp = new ConfigurationProperty ("network", typeof (SmtpNetworkElement));
                        specifiedPickupDirectoryProp = new ConfigurationProperty ("specifiedPickupDirectory", typeof (SmtpSpecifiedPickupDirectoryElement));
                        properties = new ConfigurationPropertyCollection ();

                        properties.Add (deliveryMethodProp);
                        properties.Add (fromProp);
                        properties.Add (networkProp);
                        properties.Add (specifiedPickupDirectoryProp);

                }

                [ConfigurationProperty ("deliveryMethod", DefaultValue = "Network")]
                public SmtpDeliveryMethod DeliveryMethod {
                        get { return (SmtpDeliveryMethod) base [deliveryMethodProp];}
                        set { base[deliveryMethodProp] = value; }
                }

                [ConfigurationProperty ("from")]
                public string From {
                        get { return (string) base [fromProp];}
                        set { base[fromProp] = value; }
                }

                [ConfigurationProperty ("network")]
                public SmtpNetworkElement Network {
                        get { return (SmtpNetworkElement) base [networkProp];}
                }

                [ConfigurationProperty ("specifiedPickupDirectory")]
                public SmtpSpecifiedPickupDirectoryElement SpecifiedPickupDirectory {
                        get { return (SmtpSpecifiedPickupDirectoryElement) base [specifiedPickupDirectoryProp];}
                }

                protected override ConfigurationPropertyCollection Properties {
                        get { return properties; }
                }

        }

}

#endif

==> mono_1.2.3.1.orig.tar.gz: mono-1.2.3.1/mcs/class/System/System.Net.Configuration/SmtpSection.cs <==
//
// System.Net.Configuration.SmtpSection
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0 && CONFIGURATION_DEP

using System;
using System.Configuration;
using System.Net.Mail;

namespace System.Net.Configuration {

        public sealed class SmtpSection : ConfigurationSection
        {
                [ConfigurationProperty ("deliveryMethod", DefaultValue = "Network")]
                public SmtpDeliveryMethod DeliveryMethod {
					get { return (SmtpDeliveryMethod) base ["deliveryMethod"]; }
					set { base ["deliveryMethod"] = value; }
                }

                [ConfigurationProperty ("from")]
                public string From {
					get { return (string) base ["from"]; }
					set { base ["from"] = value; }
                }

                [ConfigurationProperty ("network")]
                public SmtpNetworkElement Network {
					get { return (SmtpNetworkElement) base ["network"]; }
                }

                [ConfigurationProperty ("specifiedPickupDirectory")]
                public SmtpSpecifiedPickupDirectoryElement SpecifiedPickupDirectory {
					get { return (SmtpSpecifiedPickupDirectoryElement) base ["specifiedPickupDirectory"]; }
                }
        }

}

#endif
